@@ -1,11 +1,17 @@
-// Copyright (C) 2008-2016 National ICT Australia (NICTA)
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup diagview
@@ -16,20 +22,56 @@ template<typename eT>
 inline
 diagview<eT>::~diagview()
   {
-  arma_extra_debug_sigprint();
+  arma_extra_debug_sigprint_this(this);
   }
 
 
+
 template<typename eT>
 arma_inline
 diagview<eT>::diagview(const Mat<eT>& in_m, const uword in_row_offset, const uword in_col_offset, const uword in_len)
-  : m(in_m)
+  : m         (in_m         )
   , row_offset(in_row_offset)
   , col_offset(in_col_offset)
-  , n_rows(in_len)
-  , n_elem(in_len)
+  , n_rows    (in_len       )
+  , n_elem    (in_len       )
   {
-  arma_extra_debug_sigprint();
+  arma_extra_debug_sigprint_this(this);
+  }
+
+
+
+template<typename eT>
+inline
+diagview<eT>::diagview(const diagview<eT>& in)
+  : m         (in.m         )
+  , row_offset(in.row_offset)
+  , col_offset(in.col_offset)
+  , n_rows    (in.n_rows    )
+  , n_elem    (in.n_elem    )
+  {
+  arma_extra_debug_sigprint(arma_str::format("this = %x   in = %x") % this % &in);
+  }
+
+
+
+template<typename eT>
+inline
+diagview<eT>::diagview(diagview<eT>&& in)
+  : m         (in.m         )
+  , row_offset(in.row_offset)
+  , col_offset(in.col_offset)
+  , n_rows    (in.n_rows    )
+  , n_elem    (in.n_elem    )
+  {
+  arma_extra_debug_sigprint(arma_str::format("this = %x   in = %x") % this % &in);
+  
+  // for paranoia
+  
+  access::rw(in.row_offset) = 0;
+  access::rw(in.col_offset) = 0;
+  access::rw(in.n_rows    ) = 0;
+  access::rw(in.n_elem    ) = 0;
   }
 
 
